@@ -273,7 +273,7 @@ class RKXMLRequest(XMLRequest):
                         return item.attrib
                     menu_items_dto = MenuItemsDTO(
                         ident=(item.attrib['Ident']), item_ident=(item.attrib['ItemIdent']),
-                        sourse_ident=(item.attrib['SourceIdent']), guid_string=(item.attrib['GUIDString']),
+                        source_ident=(item.attrib['SourceIdent']), guid_string=(item.attrib['GUIDString']),
                         assign_childs_on_server=(item.attrib['AssignChildsOnServer']),
                         active_hierarchy=(item.attrib['ActiveHierarchy']), code=(item.attrib['Code']),
                         name=(item.attrib['Name']), alt_name=(item.attrib['AltName']),
