@@ -2,8 +2,10 @@ from typing import TypedDict
 
 
 class EmployeeDTO(TypedDict):
+    restaurant: str
     name: str
     altname: str
+    role: str
     gen_san_date: str
     gen_tax_payer_id_num: str
     ident: int
@@ -74,6 +76,13 @@ class MenuItemsDTO(TypedDict):
     combo_scheme: int
 
 
+class WaiterDTO(TypedDict):
+    restaurant: str
+    name: str
+    ident: int
+    code: int
+
+
 class ConnectionErrors(Exception):
     pass
 
